==> haskell-code-page-0.2.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 code-page
version:              0.2.1
visibility:           public
id:                   code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5
key:                  code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/code-page
synopsis:             Windows code page library for Haskell
description:
    This library provides two modules:

    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.

    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.

category:             System
abi:                  1984a9c9cade8edc27b505db87efe7b5
exposed:              True
exposed-modules:
    System.IO.CodePage System.IO.CodePage.Internal
    System.Win32.CodePage

import-dirs:          /usr/lib/ghc-9.0.2/site-local/code-page-0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/code-page-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/code-page-0.2.1
hs-libraries:         HScode-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html:         /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-code-page-0.2.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-code-page.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 code-page
version:              0.2.1
visibility:           public
id:                   code-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0
key:                  code-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/code-page
synopsis:             Windows code page library for Haskell
description:
    This library provides two modules:

    * "System.IO.CodePage": a cross-platform module that exports
    functions which adjust code pages on Windows, and do nothing
    on other operating systems.

    * "System.Win32.CodePage": On Windows, this exports functions
    for getting, setting, and analyzing code pages. On other
    operating systems, this module exports nothing.

category:             System
abi:                  30dfb96e66a85566ba6b2c0c6baa39c7
exposed:              True
exposed-modules:
    System.IO.CodePage System.IO.CodePage.Internal
    System.Win32.CodePage

import-dirs:          /usr/lib/ghc-9.2.8/site-local/code-page-0.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/code-page-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-code-page
hs-libraries:         HScode-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-code-page/html/code-page.haddock
haddock-html:         /usr/share/doc/haskell-code-page/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
